//
//  ViewController.swift
//  ARKit_planeDetection
//
//  Created by yoshiyuki oshige on 2018/09/12.
//  Copyright © 2018年 yoshiyuki oshige. All rights reserved.
//


import UIKit
import SceneKit
import ARKit

class ViewController: UIViewController, ARSCNViewDelegate {
    
    @IBOutlet var sceneView: ARSCNView!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        // fpsなどを表示する
        sceneView.showsStatistics = true
        // デリゲートになる
        sceneView.delegate = self
        // シーンを作る
        sceneView.scene = SCNScene()
        // デバッグ表示（ワイヤーフレーム）
        sceneView.debugOptions = .showWireframe
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        // コンフィグを作る
        let configuration = ARWorldTrackingConfiguration()
        // 平面の検出を有効化する（水平面／垂直面）
        configuration.planeDetection = [.horizontal, .vertical]
        // セッションを開始する
        sceneView.session.run(configuration)
    }
    
    override func viewWillDisappear(_ animated: Bool) {
        super.viewWillDisappear(animated)
        // セッションを止める
        sceneView.session.pause()
    }
    
    // MARK: - ARSCNViewDelegate
    // ノードが追加された
    func renderer(_ renderer: SCNSceneRenderer, didAdd node: SCNNode, for anchor: ARAnchor) {
        // 平面アンカーではないときは中断する
        guard let planeAnchor = anchor as? ARPlaneAnchor else { 
            return
        }
        // アンカーが示す位置に平面ノードを追加する
        node.addChildNode(PlaneNode(anchor: planeAnchor))
        
    }
    
    // ノードが更新された
    func renderer(_ renderer: SCNSceneRenderer, didUpdate node: SCNNode, for anchor: ARAnchor) {
        // 平面アンカーではないときは中断する
        guard let planeAnchor = anchor as? ARPlaneAnchor else {
            return
        }
        // PlaneNodeではないときは中断する
        guard let planeNode = node.childNodes.first as? PlaneNode else {
            return
        }
        // ノードの位置とサイズを更新する
        planeNode.update(anchor: planeAnchor)
    }
    
    @IBAction func restart(_ sender: Any) {
        // 現在のコンフィグ
        let configuration = sceneView.session.configuration
        // リセット後にセッションを開始する
        let runOptions:ARSession.RunOptions = [.resetTracking, .removeExistingAnchors]
        sceneView.session.run(configuration!, options: runOptions)
    }
    
    
}
