//
//  PhysicEarthNode.swift
//  ARKit_physicsBody
//
//  Created by yoshiyuki oshige on 2018/09/14.
//  Copyright © 2018年 yoshiyuki oshige. All rights reserved.
//

import SceneKit
import ARKit

class PhysicEarthNode: SCNNode {
    required init?(coder aDecoder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    override init() {
        super.init()
        // ジオメトリ
        let earth = SCNSphere(radius: 0.05) // 球体
        // テクスチャ
        earth.firstMaterial?.diffuse.contents = UIImage(named: "earth_1024") // 衛星写真
       // ノードのgeometryプロパティに設定する
        geometry = earth
        // 物理ボディを設定する
        let bodyShape = SCNPhysicsShape(geometry: geometry!, options: [:])
        physicsBody = SCNPhysicsBody(type: .dynamic, shape: bodyShape)
        physicsBody?.friction = 1.0 // 摩擦
        physicsBody?.rollingFriction = 1.0  // 回転時の摩擦
        physicsBody?.restitution = 0.5  // 反発力
        // 衝突する相手を決める（CategoryはCategory.swiftで定義している）
        physicsBody?.categoryBitMask = Category.earthCategory  // 自身のカテゴリ
        physicsBody?.collisionBitMask = Category.all // 衝突相手
    }
}
