//
//  ViewController.swift
//  ARKit_nodeHitTest
//
//  Created by yoshiyuki oshige on 2018/09/23.
//  Copyright © 2018年 yoshiyuki oshige. All rights reserved.
//

import UIKit
import SceneKit
import ARKit

class ViewController: UIViewController, ARSCNViewDelegate {
    
    @IBOutlet var sceneView: ARSCNView!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        sceneView.delegate = self // デリゲートになる
        sceneView.scene = SCNScene() // シーンを作る
        sceneView.debugOptions = .showWireframe // ワイヤーフレーム表示
        // 物理ワールドの重力を決める（落下速度を遅くする）
        sceneView.scene.physicsWorld.gravity = SCNVector3(0, -1.0, 0)
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        let configuration = ARWorldTrackingConfiguration() // コンフィグを作る
        sceneView.session.run(configuration) // セッションを開始する
    }
    
    override func viewWillDisappear(_ animated: Bool) {
        super.viewWillDisappear(animated)
        sceneView.session.pause() // セッションを止める
    }
    
    // シーンビューsceneViewをタップした
    @IBAction func tapSceneView(_ sender: UITapGestureRecognizer) {
        // タップした2D座標
        let tapLoc = sender.location(in: sceneView)
        // 2D座標のヒットテスト
        let hitTestOptions = [SCNHitTestOption:Any]()
        let results = sceneView.hitTest(tapLoc, options: hitTestOptions)
        if let result = results.first {
            // PhysicBoxNodeをクリックしたならば押す
            guard let node = result.node as? PhysicBoxNode else { return }
            let frame = sceneView.session.currentFrame! // 現在フレーム
            let tf = frame.camera.transform
            // カメラの位置
            let cameraPos = SCNVector3(tf.columns.3.x, tf.columns.3.y, tf.columns.3.z)
            // カメラとノードの距離 len
            let x = node.position.x - cameraPos.x
            let y = node.position.y - cameraPos.y
            let z = node.position.z - cameraPos.z
            let len = sqrtf(x*x + y*y + z*z)
            // カメラからノード方向への単位ベクトル
            let unitVec = SCNVector3(x/len, y/len, z/len)
            let force:Float = 2.0  // 力
            // 力のベクトル
            let forceVec = SCNVector3(force*unitVec.x, force*unitVec.y, force*unitVec.z)
            // ノードを弾くように力を加える
            node.physicsBody?.applyForce(forceVec, asImpulse: true)
            // 重力の影響を受ける設定にする
            node.physicsBody?.isAffectedByGravity = true
        } else {
            let frame = sceneView.session.currentFrame! // 現在フレーム
            // トランスフォームを作る
            var transform = matrix_identity_float4x4
            transform.columns.3.z = -0.2
            // カメラ正面の位置を作る
            let tf = simd_mul(frame.camera.transform, transform)
            let pos = SCNVector3(tf.columns.3.x, tf.columns.3.y, tf.columns.3.z)
            // ノードを作る（物理ボディ）
            let boxNode = PhysicBoxNode()
            boxNode.position = pos // 位置決めする
            sceneView.scene.rootNode.addChildNode(boxNode) // シーンに追加する
        }
    }
    
    
    // MARK: - ARSCNViewDelegate
    /*
     // Override to create and configure nodes for anchors added to the view's session.
     func renderer(_ renderer: SCNSceneRenderer, nodeFor anchor: ARAnchor) -> SCNNode? {
     let node = SCNNode()
     
     return node
     }
     */
    
    func session(_ session: ARSession, didFailWithError error: Error) {
        // Present an error message to the user
        
    }
    
    func sessionWasInterrupted(_ session: ARSession) {
        // Inform the user that the session has been interrupted, for example, by presenting an overlay
        
    }
    
    func sessionInterruptionEnded(_ session: ARSession) {
        // Reset tracking and/or remove existing anchors if consistent tracking is required
        
    }
}
