//
//  ViewController.swift
//  ARKit_lookAt
//
//  Created by yoshiyuki oshige on 2018/09/24.
//  Copyright © 2018年 yoshiyuki oshige. All rights reserved.
//

import UIKit
import SceneKit
import ARKit

class ViewController: UIViewController, ARSCNViewDelegate, ARSessionDelegate {
    @IBOutlet var sceneView: ARSCNView!

    override func viewDidLoad() {
        super.viewDidLoad()
        // デリゲートになる
        sceneView.delegate = self // ARSCNViewDelegateデリゲート
        sceneView.session.delegate = self // ARSessionDelegateデリゲート
        // シーンを作る
        let scene = SCNScene()
        sceneView.scene = scene
        // shipNodeを2機作る
        let shipNode1 = ShipNode()
        shipNode1.position = SCNVector3(0.05, 0.05, -0.3)
        let shipNode2 = ShipNode()
        shipNode2.position = SCNVector3(-0.05, -0.15, -0.2)
        // シーンに追加する
        sceneView.scene.rootNode.addChildNode(shipNode1)
        sceneView.scene.rootNode.addChildNode(shipNode2)
    }
    
    // フレーム毎に繰り返し実行する（ARSessionDelegateデリゲートメソッド）
    func session(_ session: ARSession, didUpdate frame: ARFrame){
        // カメラのトランスフォーム
        let tf = frame.camera.transform
        // カメラの位置
        let x = tf.columns.3.x
        let z = tf.columns.3.z
        // shipNodeを取り出す
        for node in sceneView.scene.rootNode.childNodes {
            if node is ShipNode {
                // 機首を水平に保つためにY軸はshipNodeの値を利用する
                let pos = SCNVector3(x, node.position.y, z)
                // カメラの方向を向く
                 node.look(at: pos)
            }
        }
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        let configuration = ARWorldTrackingConfiguration() // コンフィグを作る
        sceneView.session.run(configuration) // セッションを開始する
    }
    
    override func viewWillDisappear(_ animated: Bool) {
        super.viewWillDisappear(animated)
        sceneView.session.pause() // セッションを止める
    }
    
    // MARK: - ARSCNViewDelegate
    
/*
    // Override to create and configure nodes for anchors added to the view's session.
    func renderer(_ renderer: SCNSceneRenderer, nodeFor anchor: ARAnchor) -> SCNNode? {
        let node = SCNNode()
     
        return node
    }
*/
    
    func session(_ session: ARSession, didFailWithError error: Error) {
        // Present an error message to the user
        
    }
    
    func sessionWasInterrupted(_ session: ARSession) {
        // Inform the user that the session has been interrupted, for example, by presenting an overlay
    }
    
    func sessionInterruptionEnded(_ session: ARSession) {
        // Reset tracking and/or remove existing anchors if consistent tracking is required
    }
}
