//
//  ViewController.swift
//  ARKit_ImageRecognize
//
//  Created by yoshiyuki oshige on 2018/09/24.
//  Copyright © 2018年 yoshiyuki oshige. All rights reserved.
//

import UIKit
import SceneKit
import ARKit

class ViewController: UIViewController, ARSCNViewDelegate {

    @IBOutlet var sceneView: ARSCNView!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        sceneView.delegate = self // デリゲートになる
        sceneView.scene = SCNScene() // シーンを作る
        sceneView.debugOptions = [.showFeaturePoints] // 特徴点を表示する
    }

    override func viewWillDisappear(_ animated: Bool) {
        super.viewWillDisappear(animated)
        sceneView.session.pause() // セッションを止める
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        let configuration = ARWorldTrackingConfiguration()// コンフィグを作る
        // Assets.xcassetsの"AR Resources"グループの画像を参照する
        guard let referenceImages = ARReferenceImage.referenceImages(inGroupNamed: "AR Resources", bundle: nil) else {
            return
        }
        configuration.detectionImages = referenceImages // 参照画像を設定する
        sceneView.session.run(configuration)// セッションを開始する
    }
    
    // 画像認識
    func renderer(_ renderer: SCNSceneRenderer, didAdd node: SCNNode, for anchor: ARAnchor) {
        // 画像認識したアンカーを取り出す
        guard let imageAnchor = anchor as? ARImageAnchor else { return }
        let referenceImage = imageAnchor.referenceImage // 認識した画像の情報
        // 認識画像をハイライトする
        let plane = SCNPlane(width: referenceImage.physicalSize.width,
                             height: referenceImage.physicalSize.height)
        let planeNode = SCNNode(geometry: plane)
        planeNode.eulerAngles.x = -.pi/2 // 90度回転
        planeNode.opacity = 0.25  // 半透明
        node.addChildNode(planeNode)
        // ネームを表示する
        let name = referenceImage.name!
        let nameNode = TextNode(str:name)
        nameNode.eulerAngles.x = -.pi/2 // 90度回転
        node.addChildNode(nameNode)
    }
}
