//
//  ViewController.swift
//  DetectARRefarenceObject
//
//  Created by yoshiyuki oshige on 2018/09/23.
//  Copyright © 2018年 yoshiyuki oshige. All rights reserved.
//

import UIKit
import SceneKit
import ARKit

class ViewController: UIViewController, ARSCNViewDelegate {

    @IBOutlet var sceneView: ARSCNView!
    // セッション情報を表示するラベル
    @IBOutlet weak var sessionInfoLabel: UILabel!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        sceneView.delegate = self // デリゲートになる
        sceneView.scene = SCNScene() // シーンを作る
        sceneView.debugOptions = [.showFeaturePoints] // 特徴点を表示する
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        let configuration = ARWorldTrackingConfiguration()// コンフィグを作る
        // Assets.xcassetsの"AR Resources"グループのAR参照オブジェクトを参照する
        guard let referenceObjects = ARReferenceObject.referenceObjects(inGroupNamed: "AR Resources", bundle: nil) else {
            return
        }
        configuration.detectionObjects = referenceObjects // AR参照オブジェクトを設定する
        sceneView.session.run(configuration)// セッションを開始する
    }
    
    override func viewWillDisappear(_ animated: Bool) {
        super.viewWillDisappear(animated)
        
        // Pause the view's session
        sceneView.session.pause()
    }

    // MARK: - ARSCNViewDelegate
    
    // 物体認識
    func renderer(_ renderer: SCNSceneRenderer, didAdd node: SCNNode, for anchor: ARAnchor) {
        print(node)
        // 物体認識したアンカーを取り出す
        if let objectAnchor = anchor as? ARObjectAnchor {
            // 参照オブジェクトの情報
            let referenceObject = objectAnchor.referenceObject
            // ネームを表示する
            let nameNode = TextNode(str: referenceObject.name!)
            node.addChildNode(nameNode)
        }
    }

    // トラッキング状態をラベルに表示
    func session(_ session: ARSession, cameraDidChangeTrackingState camera: ARCamera) {
        let message: String
        // カメラのトラッキング状態
        switch camera.trackingState {
        case .notAvailable:
            message = "トラッキングできません。"
        case .normal:
            message = "正常です。"
        case .limited(.excessiveMotion):
            message = "もっとゆっくり動かしてください。"
        case .limited(.insufficientFeatures):
            message = "特徴を読み取れません。"
        case .limited(.initializing):
            message = "セッションをイニシャライズ中です。"
        case .limited(.relocalizing):
            message = "..."
        }
        sessionInfoLabel.text = message
    }
    
    func session(_ session: ARSession, didFailWithError error: Error) {
        // Present an error message to the user
        
    }
    
    func sessionWasInterrupted(_ session: ARSession) {
        // Inform the user that the session has been interrupted, for example, by presenting an overlay
    }
    
    // セッションをリセットしてトラッキングを再開する
    func sessionInterruptionEnded(_ session: ARSession) {
                let runOptions:ARSession.RunOptions = [.removeExistingAnchors,.resetTracking]
                session.run(session.configuration!, options: runOptions)
    }
}
